==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/es_EC.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Conceder acceso",
    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
    "Generate keys" : "Generar llaves",
    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
    "Forbidden to manage local mounts" : "Prohibido administrar montajes locales.",
    "Storage with ID \"%d\" not found" : "El almacenamiento con ID \"%d\" no fue encontrado",
    "Invalid backend or authentication mechanism class" : "Backend o clase de mecanismo de autenticación inválido ",
    "Invalid mount point" : "Punto de montaje inválido",
    "Objectstore forbidden" : "Objectstore prohibido",
    "Invalid storage backend \"%s\"" : "Almacenamiento de backend \"%s\" inválido ",
    "Not permitted to use backend \"%s\"" : "No está permitido usar el backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido el uso del mecanismo de autenticación \"%s\"",
    "Unsatisfied backend parameters" : "Parametros del backend no satisfechos",
    "Unsatisfied authentication mechanism parameters" : "Parámetros no satisfechos del mecanismo de autenticación",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "%s" : "%s",
    "Access key" : "Llave de acceso",
    "Secret key" : "Llave secreta",
    "Builtin" : "Integrado",
    "None" : "Ninguno",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Iniciar sesión",
    "Password" : "Contraseña",
    "Tenant name" : "Nombre de inquilino",
    "Identity endpoint URL" : "URL del punto de enlace de Identidad",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Llave de API",
    "Global credentials" : "Credenciales globales",
    "Log-in credentials, save in database" : "Credenciales de inicio de sesión, guardar en la base de datos",
    "Log-in credentials, save in session" : "Credenciales de inicio de sesión, guardar en la sesión",
    "RSA public key" : "Llave pública RSA",
    "Public key" : "Llave pública",
    "RSA private key" : "Clave privada RSA",
    "Private key" : "Clave privada",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Reino predeterminado de Kerberos, por defecto \"WORKGROUP\".",
    "Kerberos ticket Apache mode" : "Modo Apache para tickets de Kerberos.",
    "Kerberos ticket" : "Ticket de Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nombre del servidor",
    "Port" : "Puerto",
    "Region" : "Región",
    "Storage Class" : "Clase de almacenamiento",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "Legacy (v2) authentication" : "Autenticación legada (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Ubicación",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Compartir",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Verify ACL access when listing files" : "Verificar el acceso ACL al listar archivos",
    "Timeout" : "Tiempo de espera",
    "SMB/CIFS using OC login" : "SMB/CIFS utilizando inicio de sesión de OC",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "No está instalado \"%1$s\". No es posible montar %2$s. Por favor, pide a tu administrador de sistema que lo instale.",
    "External storage" : "Almacenamiento externo",
    "External storage support" : "Soporte de almacenamiento externo",
    "Adds basic external storage support" : "Añade soporte básico para almacenamiento externo.",
    "Confirm" : "Confirmar",
    "External mount error" : "Error de montaje externo",
    "Storage type" : "Tipo de almacenamiento",
    "Unknown" : "Desconocido",
    "Scope" : "Alcance",
    "Personal" : "Personal",
    "System" : "Sistema",
    "(Group)" : "(Grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac NFD (lenta)",
    "Enable encryption" : "Habilitar encripción",
    "Enable previews" : "Habilitar vistas previas",
    "Enable sharing" : "Habilitar compartir",
    "Check for changes" : "Verificar si hay cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "Read only" : "Sólo lectura",
    "Disconnect" : "Desconectar",
    "Admin defined" : "Administrador definido",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "La verificación automática de estado está desactivada debido al gran número de almacenamientos configurados, haz clic para verificar el estado.",
    "Delete storage?" : "¿Borrar almacenamiento?",
    "Click to recheck the configuration" : "Haz click para volver a marcar la configuración",
    "Saved" : "Guardado",
    "Saving …" : "Guardando...",
    "Save" : "Guardar",
    "No external storage configured or you don't have the permission to configure them" : "No se ha configurado almacenamiento externo o bien no cuentas con los permisos para configurarlos",
    "Open documentation" : "Abrir la documentación",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Add storage" : "Agregar almacenamiento",
    "Advanced settings" : "Configuraciones avanzadas",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Las credenciales globales se pueden usar para autenticarse con múltiples almacenamientos externos que tienen las mismas credenciales.",
    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
    "Please provide a valid app key and secret." : "Por favor proporciona una llave de aplicación y secreto válidos.",
    "OAuth1" : "OAuth1",
    "App key" : "Llave de la aplicación",
    "App secret" : "Secreto de la aplicación",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "¿Estás seguro de que quieres desconectar este almacenamiento externo? Esto hará que el almacenamiento no esté disponible en Nextcloud y se eliminarán estos archivos y carpetas en cualquier cliente de sincronización que esté conectado actualmente, pero no se eliminarán archivos y carpetas en el almacenamiento externo en sí.",
    "Saving …" : "Saving …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/es_EC.js <==
OC.L10N.register(
    "files_external",
    {
    "Forbidden to manage local mounts" : "Prohibido administrar montajes locales.",
    "Storage with ID \"%d\" not found" : "El almacenamiento con ID \"%d\" no fue encontrado",
    "Invalid backend or authentication mechanism class" : "Backend o clase de mecanismo de autenticación inválido ",
    "Invalid mount point" : "Punto de montaje inválido",
    "Objectstore forbidden" : "Objectstore prohibido",
    "Invalid storage backend \"%s\"" : "Almacenamiento de backend \"%s\" inválido ",
    "Not permitted to use backend \"%s\"" : "No está permitido usar el backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido el uso del mecanismo de autenticación \"%s\"",
    "Unsatisfied backend parameters" : "Parametros del backend no satisfechos",
    "Unsatisfied authentication mechanism parameters" : "Parámetros no satisfechos del mecanismo de autenticación",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "Access key" : "Llave de acceso",
    "Secret key" : "Llave secreta",
    "Builtin" : "Integrado",
    "None" : "Ninguno",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Iniciar sesión",
    "Password" : "Contraseña",
    "Tenant name" : "Nombre de inquilino",
    "Identity endpoint URL" : "URL del punto de enlace de Identidad",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Llave de API",
    "Global credentials" : "Credenciales globales",
    "Log-in credentials, save in database" : "Credenciales de inicio de sesión, guardar en la base de datos",
    "Log-in credentials, save in session" : "Credenciales de inicio de sesión, guardar en la sesión",
    "RSA public key" : "Llave pública RSA",
    "Public key" : "Llave pública",
    "RSA private key" : "Clave privada RSA",
    "Private key" : "Clave privada",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Reino predeterminado de Kerberos, por defecto \"WORKGROUP\".",
    "Kerberos ticket Apache mode" : "Modo Apache para tickets de Kerberos.",
    "Kerberos ticket" : "Ticket de Kerberos",
    "Bucket" : "Bucket",
    "Hostname" : "Nombre del servidor",
    "Port" : "Puerto",
    "Proxy" : "Proxy",
    "Region" : "Región",
    "Storage Class" : "Clase de almacenamiento",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "Legacy (v2) authentication" : "Autenticación legada (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Ubicación",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Compartir",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Verify ACL access when listing files" : "Verificar el acceso ACL al listar archivos",
    "Timeout" : "Tiempo de espera",
    "SMB/CIFS using OC login" : "SMB/CIFS utilizando inicio de sesión de OC",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
    "External storage" : "Almacenamiento externo",
    "External storage support" : "Soporte de almacenamiento externo",
    "Adds basic external storage support" : "Añade soporte básico para almacenamiento externo.",
    "Add storage" : "Agregar almacenamiento",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autenticación",
    "Cancel" : "Cancelar",
    "Edit" : "Editar",
    "Create" : "Crear",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "Read only" : "Sólo lectura",
    "Enable previews" : "Habilitar vistas previas",
    "Enable sharing" : "Habilitar compartir",
    "Enable encryption" : "Habilitar encripción",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac NFD (lenta)",
    "External storages" : "Almacenamiento externo",
    "Status" : "Estado",
    "Actions" : "Acciones",
    "Delete" : "Eliminar",
    "Saved" : "Guardado",
    "Error while saving" : "Error al guardar.",
    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
    "Key size" : "Tamaño de la llave",
    "Generate keys" : "Generar llaves",
    "Confirm" : "Confirmar",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Las credenciales globales se pueden usar para autenticarse con múltiples almacenamientos externos que tienen las mismas credenciales.",
    "Saving …" : "Guardando...",
    "Save" : "Guardar",
    "External mount error" : "Error de montaje externo",
    "Open settings" : "Abrir configuraciones",
    "Ignore" : "Ignorar",
    "Storage type" : "Tipo de almacenamiento",
    "Unknown" : "Desconocido",
    "Scope" : "Alcance",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Connected" : "Conectado",
    "Error" : "Error",
    "Unauthorized" : "No autorizado",
    "Network error" : "Error en la red",
    "Grant access" : "Conceder acceso",
    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
    "Please provide a valid app key and secret." : "Por favor proporciona una llave de aplicación y secreto válidos.",
    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
    "%s" : "%s",
    "OAuth1" : "OAuth1",
    "App key" : "Llave de la aplicación",
    "App secret" : "Secreto de la aplicación",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "No está instalado \"%1$s\". No es posible montar %2$s. Por favor, pide a tu administrador de sistema que lo instale.",
    "(Group)" : "(Grupo)",
    "Check for changes" : "Verificar si hay cambios",
    "Disconnect" : "Desconectar",
    "Admin defined" : "Administrador definido",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "La verificación automática de estado está desactivada debido al gran número de almacenamientos configurados, haz clic para verificar el estado.",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "¿Estás seguro de que quieres desconectar este almacenamiento externo? Esto hará que el almacenamiento no esté disponible en Nextcloud y se eliminarán estos archivos y carpetas en cualquier cliente de sincronización que esté conectado actualmente, pero no se eliminarán archivos y carpetas en el almacenamiento externo en sí.",
    "Delete storage?" : "¿Borrar almacenamiento?",
    "Click to recheck the configuration" : "Haz click para volver a marcar la configuración",
    "Saving …" : "Saving …",
    "No external storage configured or you don't have the permission to configure them" : "No se ha configurado almacenamiento externo o bien no cuentas con los permisos para configurarlos",
    "Open documentation" : "Abrir la documentación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Advanced settings" : "Configuraciones avanzadas"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
